#!/local/bin/bash
#-----------------------------------------------------------------------
# Abstract:
#    Extract and compare PCDATA from two XML-files after converting from
#    ODF to OOXML and vice versa.
#
# Authorship:
#    Author: Gisle Hannemyr, University of Oslo ( http://hannemyr.com/ )
#    Copyright (c) 2008 Gisle Hannemyr
#    This is free software released under GPL ver. 3.0.
#    License: http://www.gnu.org/licenses/gpl.html
#
# Portability:
#    - This tool may be downloaded if missing:
#      + Saxon:   http://saxon.sourceforge.net/
#      Set XSLT to point to the directory where the jar-files for this
#      is located.
#
# History:
#    0.00 2008 Mar 18 [gh] Wrote it.
#
# Usage:
#    econ.sh originalfile [ convertedfile]
#
# Design:
#    Nothing I can think about.
#
# Distribution:
#    See the file MANIFEST.txt that should come as part of the
#    distribution for a list of all elements.
#
#	| tr -cs '[:alnum:][:punct:]' '\012' \
#	| grep -v '^$$' > $1.txt
#-----------------------------------------------------------------------

XSLT=${HOME}/bin/Saxon

xslt() {
    echo "creating $1.txt"
    java -cp ${XSLT}/saxon.jar com.icl.saxon.StyleSheet \
	$1.xml econ.xsl \
	| econ  > $1.txt
}

echo -e "econ.sh ver. 0.0\n"

if [ $# -lt 1 ]
then
    echo "Usage: econ.sh originalfile [ convertedfile] "
    exit 1
fi
orgf=$1
bname=`econ $1 | cut -f1`
suffix=`econ $1 | cut -f2`
if [ "doc" = $suffix ]
then
    suffix="docx"
    orgf=$bname.$suffix
fi
if [ "docx" = $suffix -o "odt" = $suffix ]
then
    echo "Original format: $suffix."
else
    echo "Unknown: $suffix (first parameter must be format of original XML)."
    echo "Usage: econ.sh originalfile [ convertedfile] "
    exit 1
fi
if [ $# -eq 1 ]
then
    if [ "docx" = $suffix ]
    then
	cs="odt"
    else
	cs="docx"
    fi
    conv=$bname.$cs
else
    conv=$2
fi

#echo "[$#][$orgf][$conv]"

if [ ! -r ${XSLT}/saxon.jar ]
then
    echo "No XSLT processor in ${XSLT}.";
    exit 1
fi

make tidy > /dev/null
if [ -r Unpack/meta.xml ]
then
    echo "Junk remain, make tidy first?"
    exit 1
fi
if [ ! -r ${orgf} ]
then
    echo "Not a file: \"${orgf}\" ?"
    exit 1
fi

if [ ! -r ${conv} ]
then
    echo "Not a file: \"${conv}\" ?"
    exit 1
fi

cp ${orgf} Unpack
unzip -d Unpack Unpack/${orgf} > /dev/null
cp ${conv} Unpack
unzip -d Unpack Unpack/${conv} > /dev/null
mv Unpack/word/document.xml ooxml.xml
mv Unpack/content.xml odf.xml
rm Unpack/${orgf}
rm Unpack/${conv}

xslt ooxml
xslt odf

if [ ! -s ooxml.txt ]
then
    echo "XSLT failed for OOXML?"
    exit 1
fi

if [ ! -s odf.txt ]
then
    echo "XSLT failed for ODF?"
    exit 1
fi

# In this section, we grep for whatever we know cause problems.
# Add to this as new issues are identified, remove as they become fixed.
if [ "odt" = $suffix ]
then
    formcheckbox=`fgrep FORMCHECKBOX ooxml.txt | wc -l`
else
    formcheckbox=0
fi

# Compare the stripped files,
diff ooxml.txt odf.txt > ${bname}_d.txt

#clear
flaws=`wc -l ${bname}_d.txt | cut -d' ' -f1`
result=$[$flaws+$formcheckbox]
echo -e "\nNeglect count:  $result"
if [ $result -ne 0 ]
then
    echo " Diffs:         $flaws"
    echo " FORMCHECKBOX:  $formcheckbox"
    echo "Diffs are in:   ${bname}_d.txt."
    exit 1
else
    echo -e "The documents seem to be similar."
fi

# Uncomment exit if you don't want the files for post-mortem
# examination in case of success.
exit 0
rm -fr	Unpack/*
rm ooxml.txt odf.txt ooxml.xml odf.xml *~

# EOF
