#!/local/bin/perl
#-----------------------------------------------------------------------------
# Abstract:
#    Perl script to read a list of URLs and local file names (tab separated).
#    Will then download them all (if possible to local directory).
#    Log of session written to dl_log.csv.
#    
# Authorship:
#    Author: Gisle Hannemyr, University of Oslo ( http://hannemyr.com/ )
#    This is free software released under GPL ver. 3.0.
#    License: http://www.gnu.org/licenses/gpl.html
#
# Design:
#    See enclosed dl_list.txt for example of file format.
#-----------------------------------------------------------------------------

use LWP::Simple;

$err = $cnt = 0;
sub proc_line {
    ($url, $local) = split;
    $stat = getstore ($url, $local);
    print(LOG $tstamp , ";", $stat, ";", $url, ";", $local, "\n");
    if ($stat != 200) {
	print(STDERR "Server error, status code: ", $stat, ": ", $url, "\n");
	$err++;
    } else {
	$cnt++;
    }
}

$now = time;
($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime($now);
$tstamp = sprintf("%4d-%02d-%02d", $year+1900, $mon+1, $mday);

open(LOG, ">dl_log.csv") || die "dl_list.log: $!";

if ($#ARGV < 0) {
    open (DLLIST, "dl_list.txt") || die "dl_list.txt not found.\n";
    while (<DLLIST>) { proc_line; }
} else {
    while (<>) {       proc_line; }
}

close(LOG);

print "Success: $cnt documents. Failure: $err documents.\n";
exit($err);

# EOF
